==> qt5-declarative-5.8.0-1-armv7h.pkg.tar.xz: usr/include/qt/QtQml/qqmlextensionplugin.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtQml module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QQMLEXTENSIONPLUGIN_H
#define QQMLEXTENSIONPLUGIN_H

#include <QtCore/qplugin.h>
#include <QtCore/QUrl>
#include <QtQml/qqmlextensioninterface.h>

QT_BEGIN_NAMESPACE

class QQmlEngine;
class QQmlExtensionPluginPrivate;

class Q_QML_EXPORT QQmlExtensionPlugin
    : public QObject
    , public QQmlExtensionInterface
{
    Q_OBJECT
    Q_DECLARE_PRIVATE(QQmlExtensionPlugin)
    Q_INTERFACES(QQmlExtensionInterface)
    Q_INTERFACES(QQmlTypesExtensionInterface)
public:
    explicit QQmlExtensionPlugin(QObject *parent = Q_NULLPTR);
    ~QQmlExtensionPlugin();

    QUrl baseUrl() const;

    virtual void registerTypes(const char *uri) = 0;
    virtual void initializeEngine(QQmlEngine *engine, const char *uri);

private:
    Q_DISABLE_COPY(QQmlExtensionPlugin)
};

QT_END_NAMESPACE

#endif // QQMLEXTENSIONPLUGIN_H

==> qt5-declarative-5.9.1-3-armv7h.pkg.tar.xz: usr/include/qt/QtQml/qqmlextensionplugin.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtQml module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QQMLEXTENSIONPLUGIN_H
#define QQMLEXTENSIONPLUGIN_H

#include <QtCore/qplugin.h>
#include <QtCore/QUrl>
#include <QtQml/qqmlextensioninterface.h>

QT_BEGIN_NAMESPACE

class QQmlEngine;
class QQmlExtensionPluginPrivate;

class Q_QML_EXPORT QQmlExtensionPlugin
    : public QObject
    , public QQmlExtensionInterface
{
    Q_OBJECT
    Q_DECLARE_PRIVATE(QQmlExtensionPlugin)
    Q_INTERFACES(QQmlExtensionInterface)
    Q_INTERFACES(QQmlTypesExtensionInterface)
public:
    explicit QQmlExtensionPlugin(QObject *parent = Q_NULLPTR);
    ~QQmlExtensionPlugin();

    QUrl baseUrl() const;

    void registerTypes(const char *uri) override = 0;
    void initializeEngine(QQmlEngine *engine, const char *uri) override;

private:
    Q_DISABLE_COPY(QQmlExtensionPlugin)
};

QT_END_NAMESPACE

#endif // QQMLEXTENSIONPLUGIN_H
